==> estateplat-common-1.2.4-20210608.061321-786-sources.jar: cn/gtmap/estateplat/model/server/core/BdcWsmx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020-3-19
 * @description 完税信息明细表
 */
@Entity
@Table(name = "bdc_wsmx")
public class BdcWsmx {
    @Id
    @Column
    private String wsmxid;//主键
    @Column
    private String wsxxid;//完税信息主键
    @Column
    private Double jsje;//计税金额
    @Column
    private Double kce;//扣除额
    @Column
    private Double kssl;//课税数量
    @Column
    private Double sjje;//实际缴纳税额
    @Column
    private Date sksssq;//税款所属期
    @Column
    private Double sl;//税率
    @Column
    private String sz;//税种
    @Column
    private String zspmmc;//税目

    public String getWsmxid() {
        return wsmxid;
    }

    public void setWsmxid(String wsmxid) {
        this.wsmxid = wsmxid;
    }

    public String getWsxxid() {
        return wsxxid;
    }

    public void setWsxxid(String wsxxid) {
        this.wsxxid = wsxxid;
    }

    public Double getJsje() {
        return jsje;
    }

    public void setJsje(Double jsje) {
        this.jsje = jsje;
    }

    public Double getKce() {
        return kce;
    }

    public void setKce(Double kce) {
        this.kce = kce;
    }

    public Double getKssl() {
        return kssl;
    }

    public void setKssl(Double kssl) {
        this.kssl = kssl;
    }

    public Double getSjje() {
        return sjje;
    }

    public void setSjje(Double sjje) {
        this.sjje = sjje;
    }

    public Date getSksssq() {
        return sksssq;
    }

    public void setSksssq(Date sksssq) {
        this.sksssq = sksssq;
    }

    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }

    public String getSz() {
        return sz;
    }

    public void setSz(String sz) {
        this.sz = sz;
    }

    public String getZspmmc() {
        return zspmmc;
    }

    public void setZspmmc(String zspmmc) {
        this.zspmmc = zspmmc;
    }
}

==> estateplat-common-1.2.4-20210617.013848-793-sources.jar: cn/gtmap/estateplat/model/server/core/BdcWsmx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020-3-19
 * @description 完税信息明细表
 */
@Entity
@Table(name = "bdc_wsmx")
public class BdcWsmx {
    @Id
    @Column
    private String wsmxid;//主键
    @Column
    private String wsxxid;//完税信息主键
    @Column
    private Double jsje;//计税金额
    @Column
    private Double kce;//扣除额
    @Column
    private Double kssl;//课税数量
    @Column
    private Double sjje;//实际缴纳税额
    @Column
    private Date sksssq;//税款所属期
    @Column
    private Double sl;//税率
    @Column
    private String sz;//税种
    @Column
    private String zspmmc;//税目
    @Column
    private Date sksssqks;//税款所属期开始
    @Column
    private Date sksssqjs;//税款所属期结束
    @Column
    private String jsyj;//计税依据

    public Date getSksssqks() {
        return sksssqks;
    }

    public void setSksssqks(Date sksssqks) {
        this.sksssqks = sksssqks;
    }

    public Date getSksssqjs() {
        return sksssqjs;
    }

    public void setSksssqjs(Date sksssqjs) {
        this.sksssqjs = sksssqjs;
    }

    public String getJsyj() {
        return jsyj;
    }

    public void setJsyj(String jsyj) {
        this.jsyj = jsyj;
    }

    public String getWsmxid() {
        return wsmxid;
    }

    public void setWsmxid(String wsmxid) {
        this.wsmxid = wsmxid;
    }

    public String getWsxxid() {
        return wsxxid;
    }

    public void setWsxxid(String wsxxid) {
        this.wsxxid = wsxxid;
    }

    public Double getJsje() {
        return jsje;
    }

    public void setJsje(Double jsje) {
        this.jsje = jsje;
    }

    public Double getKce() {
        return kce;
    }

    public void setKce(Double kce) {
        this.kce = kce;
    }

    public Double getKssl() {
        return kssl;
    }

    public void setKssl(Double kssl) {
        this.kssl = kssl;
    }

    public Double getSjje() {
        return sjje;
    }

    public void setSjje(Double sjje) {
        this.sjje = sjje;
    }

    public Date getSksssq() {
        return sksssq;
    }

    public void setSksssq(Date sksssq) {
        this.sksssq = sksssq;
    }

    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }

    public String getSz() {
        return sz;
    }

    public void setSz(String sz) {
        this.sz = sz;
    }

    public String getZspmmc() {
        return zspmmc;
    }

    public void setZspmmc(String zspmmc) {
        this.zspmmc = zspmmc;
    }
}
